@@ -115,17 +115,15 @@ class LimelightController(VisionEstimator):
 
         for limelight in self.limelights:
             est_pose = limelight.get_bot_pose()
-            if est_pose:
-                pose_list.append(
-                    (
-                        Pose3d(
-                            Translation3d(est_pose[0], est_pose[1], est_pose[2]),
-                            Rotation3d(est_pose[3], est_pose[4], est_pose[5])
-                        ),
-                        Timer.getFPGATimestamp()
-                    )
-                )
-            else:
-                pose_list.append((None, None))
+
+            pose_list.append(
+                (
+                    Pose3d(
+                        Translation3d(est_pose[0], est_pose[1], est_pose[2]),
+                        Rotation3d(est_pose[3], est_pose[4], est_pose[5])
+                    ),
+                    Timer.getFPGATimestamp()
+                ) if est_pose else (None, None)
+            )
 
         return pose_list if pose_list else None
